
__docformat__ = 'restructuredtext'

from persistent import Persistent
from pyramid.events import subscriber
from zope.component.interfaces import ISite
from zope.container.contained import Contained
from zope.interface import implementer
from zope.lifecycleevent.interfaces import IObjectAddedEvent
from zope.schema.fieldproperty import FieldProperty

from onf_website.reference.planning.interfaces import IPlanningTable
from pyams_i18n.interfaces import II18nManager
from pyams_utils.traversing import get_parent


@implementer(IPlanningTable, II18nManager)
class PlanningTable(Persistent, Contained):
    """Planning table manager"""

    title = FieldProperty(IPlanningTable['title'])
    short_name = FieldProperty(IPlanningTable['short_name'])

    languages = FieldProperty(II18nManager['languages'])

    planning_displays = FieldProperty(IPlanningTable['planning_displays'])


@subscriber(IObjectAddedEvent, context_selector=IPlanningTable)
def handle_added_planning_table(event):
    """Handle new planning table"""
    site = get_parent(event.object, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, IPlanningTable)
