
"""PyAMS_*** module

"""

from zope.interface import Interface

from onf_website.component.hearing import IHearingInfo
from onf_website.shared.common.skin.head import BaseHeaderPortletRenderer
from onf_website.shared.planning import IPlanningManager
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.component.illustration import IIllustration
from pyams_content.features.alert.interfaces import ALERT_GRAVITY_NAMES, IAlertContainer
from pyams_content.features.renderer.interfaces import HIDDEN_RENDERER_NAME
from pyams_content.shared.common.portlet.interfaces import ISharedContentHeaderPortletSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config


__docformat__ = 'restructuredtext'

from onf_website import _
from pyams_utils.registry import query_utility


@adapter_config(name='ONF::head-planning',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-planning.pt', layer=IONFBaseLayer)
class PlanningHeaderPortletRenderer(BaseHeaderPortletRenderer):
    """Planning header portlet renderer"""

    label = _("ONF: Planning header")
    weight = 70

    def get_illustration(self):
        illustration = IIllustration(self.context, None)
        if (illustration is not None) and illustration.has_data():
            if illustration.renderer != HIDDEN_RENDERER_NAME:
                return illustration
        manager = query_utility(IPlanningManager)
        if manager is None:
            return None
        planning, info_planning = self.context.planning_refs[0]
        if planning.departement_situation.startswith('97'):
            adapter_name = 'dom'
        else:
            adapter_name = ''
        illustration = self.request.registry.queryAdapter(manager, IIllustration,
                                                          name=adapter_name)
        if adapter_name and \
                ((illustration is None) or
                 (not illustration.has_data()) or
                 (illustration.renderer == HIDDEN_RENDERER_NAME)):
            illustration = self.request.registry.queryAdapter(manager, IIllustration,
                                                              name='')
        return illustration
